@@ -373,6 +373,9 @@ namespace Oxygen
         //* true if style was compiled for and is running on X11
         static bool isX11( void );
 
+        //* true if running on platform Wayland
+        static bool isWayland( void );
+
         //@}
 
         #if OXYGEN_HAVE_X11
